==> kitec-lib-5.1.0-20140630.072204-1.jar: jp/kitec/lib/geom/KPathLine2d.java <==
/**
 *
 */
package jp.kitec.lib.geom;

import jp.kitec.kwt.IRichGraphics;
import jp.kitec.kwt.KArea;
import jp.kitec.lib.util.MathUtil;


/**
 * パス構成要素
 * @since 2007/10/12
 * @author kamimura
 * @version 2007/10/12
 */
public class KPathLine2d extends KPath2d {

	/**
	 * コンストラクタ.
	 * @since 2007/10/12
	 * @author kamimura
	 */
	public KPathLine2d() {
	}

	/**
	 * @return the type
	 */
	@Override
	public int getType() {
		return IRichGraphics.DEF_SEG_LINE;
	}

	@Override
	public int getNumberSize() {
		return 2;
	}

	@Override
	public double getX(double x1, double t) {
		return x1 + (mX1 - x1) * t;
	}

	@Override
	public double getY(double y1, double t) {
		return y1 + (mY1 - y1) * t;
	}

	/**
	 * @param d
	 * @param la
	 * @param shape
	 * @since 2007/10/12
	 * @author kamimura
	 * @version 2007/10/12
	 */
	@Override
	public void appendPath(IRichGraphics d, KLocalAxis la, KLocalAxis la2){
		double currx = mX1;
		double curry = mY1;

		if (la != null) {
			currx = la.getGlobalX(mX1, mY1);
			curry = la.getGlobalY(mX1, mY1);
		}
		d.pathLineTo(currx, curry, la2);
	}

	/**
	 * @param points
	 * @since 2007/10/12
	 * @author kamimura
	 * @version 2007/10/12
	 */
	@Override
	public void getPoints(double[] points){
		points[0] = mX1;//mP1.x;
		points[1] = mY1;//mP1.y;
	}

	/**
	 * @param area
	 * @param x1
	 * @param y1
	 * @since 2007/10/12
	 * @author kamimura
	 * @version 2007/10/12
	 */
	@Override
	public void updateMinMax(KArea area, double x1, double y1){
		area.updateMinMax(mX1, mY1);
		area.updateMinMax(x1, y1);
	}

	@Override
	public double distanceTo(double x, double y, double x1, double y1, int div) {
		return MathUtil.getLengthLineSegmentToPoint2D(x, y, x1, y1, mX1, mY1);
	}
}

==> kitec-lib-5.3.0-20160129.084724-2.jar: jp/kitec/lib/geom/KPathLine2d.java <==
/**
 *
 */
package jp.kitec.lib.geom;

import jp.kitec.lib.kwt.IRichGraphics;
import jp.kitec.lib.kwt.KArea;
import jp.kitec.lib.util.MathUtil;


/**
 * パス構成要素
 * @since 2007/10/12
 * @author kamimura
 * @version 2007/10/12
 */
public class KPathLine2d extends KPath2d {

	/**
	 * コンストラクタ.
	 * @since 2007/10/12
	 * @author kamimura
	 */
	public KPathLine2d() {
	}

	/**
	 * @return the type
	 */
	@Override
	public int getType() {
		return IRichGraphics.DEF_SEG_LINE;
	}

	@Override
	public int getNumberSize() {
		return 2;
	}

	@Override
	public double getX(double x1, double t) {
		return x1 + (mX1 - x1) * t;
	}

	@Override
	public double getY(double y1, double t) {
		return y1 + (mY1 - y1) * t;
	}

	/**
	 * @param d
	 * @param la
	 * @param shape
	 * @since 2007/10/12
	 * @author kamimura
	 * @version 2007/10/12
	 */
	@Override
	public void appendPath(IRichGraphics d, KLocalAxis la, KLocalAxis la2){
		double currx = mX1;
		double curry = mY1;

		if (la != null) {
			currx = la.getGlobalX(mX1, mY1);
			curry = la.getGlobalY(mX1, mY1);
		}
		d.pathLineTo(currx, curry, la2);
	}

	/**
	 * @param points
	 * @since 2007/10/12
	 * @author kamimura
	 * @version 2007/10/12
	 */
	@Override
	public void getPoints(double[] points){
		points[0] = mX1;//mP1.x;
		points[1] = mY1;//mP1.y;
	}

	/**
	 * @param area
	 * @param x1
	 * @param y1
	 * @since 2007/10/12
	 * @author kamimura
	 * @version 2007/10/12
	 */
	@Override
	public void updateMinMax(KArea area, double x1, double y1){
		area.updateMinMax(mX1, mY1);
		area.updateMinMax(x1, y1);
	}

	@Override
	public double distanceTo(double x, double y, double x1, double y1, int div) {
		return MathUtil.getLengthLineSegmentToPoint2D(x, y, x1, y1, mX1, mY1);
	}
}
